@@ -71,6 +71,7 @@ class CPHDHeaderBase(object):
     _required = ()
 
     def __init__(self, **kwargs):
+        # intended as an abstract object
         pass
 
     @classmethod
@@ -298,7 +299,7 @@ class CPHDType(Serializable):
             for el in GeoInfo:
                 self.addGeoInfo(el)
         else:
-            raise ('GeoInfo got unexpected type {}'.format(type(GeoInfo)))
+            raise ValueError('GeoInfo got unexpected type {}'.format(type(GeoInfo)))
 
         super(CPHDType, self).__init__(**kwargs)
 
